==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/UpdateOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UpdateOptionsBuilder extends UpdateOptionsFluentImpl<UpdateOptionsBuilder> implements VisitableBuilder<UpdateOptions,UpdateOptionsBuilder>{
  public UpdateOptionsBuilder() {
    this(false);
  }
  public UpdateOptionsBuilder(Boolean validationEnabled) {
    this(new UpdateOptions(), validationEnabled);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UpdateOptions(), validationEnabled);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,UpdateOptions instance) {
    this(fluent, instance, false);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,UpdateOptions instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withDryRun(instance.getDryRun());
      fluent.withFieldManager(instance.getFieldManager());
      fluent.withFieldValidation(instance.getFieldValidation());
      fluent.withKind(instance.getKind());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UpdateOptionsBuilder(UpdateOptions instance) {
    this(instance,false);
  }
  public UpdateOptionsBuilder(UpdateOptions instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withDryRun(instance.getDryRun());
      this.withFieldManager(instance.getFieldManager());
      this.withFieldValidation(instance.getFieldValidation());
      this.withKind(instance.getKind());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UpdateOptionsFluent<?> fluent;
  Boolean validationEnabled;
  public UpdateOptions build() {
    UpdateOptions buildable = new UpdateOptions(fluent.getApiVersion(),fluent.getDryRun(),fluent.getFieldManager(),fluent.getFieldValidation(),fluent.getKind());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/UpdateOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UpdateOptionsBuilder extends UpdateOptionsFluent<UpdateOptionsBuilder> implements VisitableBuilder<UpdateOptions,UpdateOptionsBuilder>{
  public UpdateOptionsBuilder() {
    this(false);
  }
  public UpdateOptionsBuilder(Boolean validationEnabled) {
    this(new UpdateOptions(), validationEnabled);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UpdateOptions(), validationEnabled);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,UpdateOptions instance) {
    this(fluent, instance, false);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,UpdateOptions instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new UpdateOptions());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withDryRun(instance.getDryRun());
      fluent.withFieldManager(instance.getFieldManager());
      fluent.withFieldValidation(instance.getFieldValidation());
      fluent.withKind(instance.getKind());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withDryRun(instance.getDryRun());
      fluent.withFieldManager(instance.getFieldManager());
      fluent.withFieldValidation(instance.getFieldValidation());
      fluent.withKind(instance.getKind());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UpdateOptionsBuilder(UpdateOptions instance) {
    this(instance,false);
  }
  public UpdateOptionsBuilder(UpdateOptions instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new UpdateOptions());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withDryRun(instance.getDryRun());
      this.withFieldManager(instance.getFieldManager());
      this.withFieldValidation(instance.getFieldValidation());
      this.withKind(instance.getKind());
      this.withApiVersion(instance.getApiVersion());
      this.withDryRun(instance.getDryRun());
      this.withFieldManager(instance.getFieldManager());
      this.withFieldValidation(instance.getFieldValidation());
      this.withKind(instance.getKind());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UpdateOptionsFluent<?> fluent;
  Boolean validationEnabled;
  public UpdateOptions build() {
    UpdateOptions buildable = new UpdateOptions(fluent.getApiVersion(),fluent.getDryRun(),fluent.getFieldManager(),fluent.getFieldValidation(),fluent.getKind());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
